{ config, pkgs, ... }:

let
  wacom-config = pkgs.substituteAll {
    name = "wacom-config";
    src = ../wacom-config.sh;
    dir = "bin";
    isExecutable = true;
  };
in
{
  services = {
    dbus.packages = with pkgs; [ dconf ];
    # $ nix-shell -p usbutils
    # $ lsusb
    # ID <idVendor>:<idProduct>
    # Gets stored in /etc/udev/rules.d/99-wacom.rules
    udev.extraRules = ''
      ACTION=="add",
      SUBSYSTEMS=="usb",
      ATTRS{idVendor}="056a",
      ATTRS{idProduct}="0302",
      RUN+="${wacom-config}/bin/wacom-config"
    '';
    xserver = {
      enable = true;
      wacom.enable = true;
      libinput = {
        enable = true;
        touchpad.tapping = true;
      };
      xkbOptions = "caps:escape";
      displayManager = {
        lightdm = {
          enable = true;
          greeters.gtk = {
            enable = true;
            theme = {
              name = "Nordic";
              package = pkgs.nordic;
            };
          };
        };
        autoLogin = {
          enable = true;
          user = "elnu";
        };
        defaultSession = "none+i3";
      };
      windowManager.i3 = {
        enable = true;
        package = pkgs.i3-gaps;
      };
    };
  };

  # To prevent `Unit dconf.service not found.` after theming GTK in HM
  programs.dconf.enable = true;

  sound.enable = true;
  hardware.pulseaudio.enable = true;
  nixpkgs.config.pulseaudio = true;

  fonts.fonts = with pkgs; [
    noto-fonts
    noto-fonts-cjk
    (nerdfonts.override { fonts = [ "FiraCode" ]; }) # required for icons
  ];
}
